==> concurrent_tasks-0.1.0.tar.gz: concurrent_tasks-0.1.0/concurrent_tasks/threaded_pool/blocking.py <==
from __future__ import annotations

from concurrent import futures
from contextlib import AbstractContextManager
from typing import (
    AsyncContextManager,
    Awaitable,
    ContextManager,
    Optional,
    TypeVar,
    Union,
)

from concurrent_tasks.threaded_pool.base import BaseThreadedTaskPool

T = TypeVar("T")


class BlockingThreadedTaskPool(AbstractContextManager):
    """Task pool running asynchronous tasks in another dedicated thread."""

    def __init__(
        self,
        name: Optional[str] = None,
        size: int = 0,
        timeout: Optional[float] = None,
        context_manager: Optional[Union[ContextManager, AsyncContextManager]] = None,
    ):
        self._base = BaseThreadedTaskPool(name, size, timeout, context_manager)

    def __enter__(self) -> "BlockingThreadedTaskPool":
        self._base.start()
        self._base.post_start().result()
        return self

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        self._base.pre_stop(exc_type, exc_val, exc_tb).result()
        self._base.stop()

    def start(self) -> None:
        self.__enter__()

    def stop(self) -> None:
        self.__exit__(None, None, None)

    def create_task(self, coro: Awaitable[T]) -> futures.Future[T]:
        """Create a task, not waiting for it to complete."""
        return self._base.create_task(coro)

    def run(self, coro: Awaitable[T]) -> T:
        """Create a task and wait for completion."""
        future = self._base.create_task(coro)
        return future.result()

==> concurrent_tasks-1.8.1.tar.gz: concurrent_tasks-1.8.1/concurrent_tasks/threaded_pool/blocking.py <==
from concurrent import futures
from contextlib import AbstractContextManager
from typing import (
    AsyncContextManager,
    Awaitable,
    ContextManager,
    Optional,
    TypeVar,
    Union,
)

from typing_extensions import Self

from concurrent_tasks.threaded_pool.base import BaseThreadedTaskPool

T = TypeVar("T")


class BlockingThreadedTaskPool(AbstractContextManager):
    """Task pool running asynchronous tasks in another dedicated thread."""

    def __init__(
        self,
        name: Optional[str] = None,
        size: int = 0,
        timeout: Optional[float] = None,
        context_manager: Optional[Union[ContextManager, AsyncContextManager]] = None,
        daemon: bool = False,
    ):
        self._base = BaseThreadedTaskPool(
            name,
            size,
            timeout,
            context_manager,
            daemon,
        )

    def __enter__(self) -> Self:
        self._base.start()
        self._base.post_start().result()
        return self

    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
        self._base.pre_stop(exc_type, exc_val, exc_tb).result()
        self._base.stop()

    def start(self) -> None:
        self.__enter__()

    def stop(self) -> None:
        self.__exit__(None, None, None)

    def create_task(self, coro: Awaitable[T]) -> futures.Future[T]:
        """Create a task, not waiting for it to complete."""
        return self._base.create_task(coro)

    def run(self, coro: Awaitable[T]) -> T:
        """Create a task and wait for completion."""
        future = self._base.create_task(coro)
        return future.result()
